Skip to contents

Use this when you have compiled the fastsem library yourself (e.g. with nimble buildRnim in the fastsem source tree) and want to use that build instead of the downloaded release binary. Also useful for development and testing without internet access.

Usage

fastsem_load(lib_path = NULL)

Arguments

lib_path

Character. Path to:

  • libfastsem_r.so on Linux,

  • libfastsem_r.dylib on macOS, or

  • libfastsem_r.dll on Windows.

When NULL (default) the function looks for any of those file names in the current working directory.

Value

Invisibly TRUE on success.

See also

fastsem_install() to download a pre-built release binary.

Examples

if (FALSE) { # \dontrun{
# Point to a local build
fastsem_load("~/fastsem/libfastsem_r.so")

# Load from the current working directory (default search)
fastsem_load()
} # }