A convenience shorthand for fastsem_install(force = TRUE). Use this
whenever a new version of fastsem is released to pull the updated binary.
See also
fastsem_install() for the full install function.
A convenience shorthand for fastsem_install(force = TRUE). Use this
whenever a new version of fastsem is released to pull the updated binary.
fastsem_install() for the full install function.